import { BasicColumn, FormSchema } from '/@/components/Table';
import { optionsListApi } from '/@/api/tigerapi/wms/finishedwarehouse';
import { h, unref } from 'vue';
import { Tag } from 'ant-design-vue';
import { useI18n } from '/@/hooks/web/useI18n';
import { useLocale } from '/@/locales/useLocale';
const { getLocale } = useLocale();
const { t: bt } = useI18n();

export const columns: BasicColumn[] = [
  {
    title: '单据代码',
    dataIndex: 'BILLCODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: '单据日期',
    dataIndex: 'BILLDATE',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('创建时间'),
    dataIndex: 'CREATE_TIME',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('修改时间'),
    dataIndex: 'UPDATE_TIME',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('T100单据代码'),
    dataIndex: 'ERP_BILL_CODE',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: '单据状态',
    dataIndex: 'STATUS',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '新增';
          color = '#C2C247';
          break;
        case 1:
          text = '已审核';
          color = '#C2C247';
          break;
        case 2:
          text = '作业中';
          color = 'blue';
          break;
        case 3:
          text = '完成';
          color = 'green';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: '创建人',
    dataIndex: 'CREATE_USER',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: '创建时间',
    dataIndex: 'CREATE_TIME',
    resizable: true,
    sorter: true,
    width: 180,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'BILLCODE',
    label: '单据代码',
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'BILLDATE',
    label: '单据日期',
    colProps: { span: 8 },
    component: 'RangePicker',
  },
  {
    field: 'STATUS',
    label: '单据状态',
    component: 'ApiSelect',
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: 'Desc',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
    colProps: { span: 8 },
  },
];

//完工 库入单(WMS)明细
export const columns_D: BasicColumn[] = [
  {
    title: bt('序号'),
    dataIndex: 'BILLLINE',
    resizable: true,
    sorter: true,
    width: 100,
  },
  {
    title: bt('物料编码'),
    dataIndex: 'ITEM_CODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: bt('需求数量'),
    dataIndex: 'PRQTY',
    resizable: true,
    sorter: true,
    width: 100,
  }, {
    title: bt('已入数量'),
    dataIndex: 'INSTOCKQTY',
    resizable: true,
    sorter: true,
    width: 100,
  },
  {
    title: bt('欠入数量'),
    dataIndex: 'OWEIN_QTY',
    resizable: true,
    sorter: true,
    width: 100,
  },
  {
    title: bt('修改时间'),
    dataIndex: 'UPDATE_TIME',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('状态'),
    dataIndex: 'LINESTATUS',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.LINESTATUS;
      let text = '';
      let color = '';
      switch (status) {
        case '0':
          text = bt('新增');
          color = 'blue';
          break;
        case '1':
          text = bt('作业中');
          color = '#C2C247';
          break;
        case '2':
          text = bt('完成');
          color = '#C2C247';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
]

export const columns_S: BasicColumn[] = [
  {
    title: bt('条码'),
    dataIndex: 'SN',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: bt('物料编码'),
    dataIndex: 'ITEM_CODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: bt('修改时间'),
    dataIndex: 'UPDATE_TIME',
    resizable: true,
    sorter: true,
    width: 180,
  },
  // {
  //   title: bt('状态'),
  //   dataIndex: 'LINESTATUS',
  //   resizable:true,
  //   customRender: ({ record }) => {
  //     console.log('record', record);
  //     const status = record.LINESTATUS;
  //     let text = '';
  //     let color = '';
  //     switch (status) {
  //       case '0':
  //         text = bt('新增');
  //         color = 'blue';
  //         break;
  //       case '1':
  //         text = bt('作业中');
  //         color = '#C2C247';
  //         break;
  //       case '2':
  //         text = bt('完成');
  //         color = '#C2C247';
  //         break;
  //       case '3':
  //         text = bt('调拨完成');
  //         color = 'green';
  //         break;
  //       default:
  //         break;
  //     }
  //     return h(Tag, { color: color }, () => text);
  //   },
  // },
  {
    title: bt('数量'),
    dataIndex: 'Qty',
    resizable: true,
    sorter: true,
    width: 200,
  },
];

export const searchFormSchema_D: FormSchema[] = [
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'LINESTATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  }
];
export const searchFormSchema_S: FormSchema[] = [
  // {
  //   field: 'BILLCODE',
  //   label: bt('单据代码'),
  //   colProps: { span: 8 },
  //   component: 'Input',
  // },
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'SN',
    label: bt('条码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  // {
  //   field: 'LINESTATUS',
  //   label: bt('状态'),
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     api: optionsListApi,
  //     resultField: 'Data',
  //     labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
  //     valueField: 'Value',
  //   },
  // }
];



